# Major
%define major		3
%define libver		1.1.0

# Library names
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%bcond_with python

Summary:	Library for creating a socket to send and receive messages
Name:		arcus
Epoch:		1
Version:	5.3.0
Release:	%mkrel 2
License:	LGPLv3+
Group:		Development/Other
URL:		https://github.com/Ultimaker/libArcus
Source0:	%{url}/archive/%{version}/lib%{name}-%{version}.tar.gz
# Python bits
Source1:	https://github.com/Ultimaker/pyArcus/archive/%{version}/pyArcus-%{version}.tar.gz
# Cmake bits taken from 4.13.1, before upstream went nuts with conan
Source2:	FindSIP.cmake
Source3:	SIPMacros.cmake
Source4:	CMakeLists.txt
Source5:	CPackConfig.cmake
Source6:	ArcusConfig.cmake.in
Source7:	COPYING-CMAKE-SCRIPTS

# https://bugzilla.redhat.com/show_bug.cgi?id=1601917
Patch1:		libArcus-3.10.0-PyQt6.sip.patch

# Actually export symbols
Patch2:		libArcus-5.2.2-actually-export-symbols.patch

Patch3:		0001-Fix-compatibility-for-protobuf-v26.x-and-later.patch

BuildRequires:	cmake
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(protobuf)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-protobuf
BuildRequires:	python3-pyqt6-sip
#BuildRequires:	python3-sip-devel

%description
This library contains a C++ and Python3 class for creating a socket
in a thread and using this socket to send and receive messages based
on the Protocol Buffers library.
It is designed to facilitate the communication between Cura and its backend
and similar code.

%package -n	%{libname}
Summary:	Runtime library for Arcus
Group:		System/Libraries

%if %{without python}
Obsoletes:	python3-arcus < %{epoch}:%{version}-%{release}
%endif

%description -n	%{libname}
This library contains a C++ and Python3 class for creating a socket
in a thread and using this socket to send and receive messages based
on the Protocol Buffers library.
It is designed to facilitate the communication between Cura and its backend
and similar code.

This package contains the shared Arcus library.

%package -n	%{develname}
Summary:	Arcus C++ headers and libraries
Group:		Development/Other
Requires:	%{libname} = %{epoch}:%{version}
Provides:	%{name}-devel = %{epoch}:%{version}-%{release}

%description -n	%{develname}
This package contains Arcus C++ headers and libraries.

%if %{with python}
%package -n     python3-arcus
Summary:	Python 3 libArcus bindings
Group:		Development/Python
%{?_sip_api:Requires: python3-pyqt6-sip-api(%{_sip_api_major}) >= %{_sip_api}}
%{?python_provide:%python_provide python3-arcus}

Conflicts:	%{_lib}arcus1 < 15.10-10

%description -n python3-arcus
Arcus Python 3 bindings for creating a socket in a thread and using this
socket to send and receive messages based on the
Protocol Buffers library. It is designed to facilitate the communication
between Cura and its backend and similar code.
%endif

%prep
%setup -q -n libArcus-%{version} -a1

cp -a pyArcus-%{version}/python .
cp -a pyArcus-%{version}/include/pyArcus include
mkdir cmake
cp -a %{SOURCE2} %{SOURCE3} %{SOURCE7} cmake/
rm -rf CMakeLists.txt
cp -a %{SOURCE4} %{SOURCE5} %{SOURCE6} .
cp -a pyArcus-%{version}/src/PythonMessage.cpp python/

%autopatch -p1

%build
%cmake \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	%{!?with_python:-DBUILD_PYTHON=OFF} \
	-DBUILD_EXAMPLES:BOOL=OFF
%cmake_build

%install
%cmake_install

%files -n %{libname}
%doc README.md
%license LICENSE
%{_libdir}/libArcus.so.%{major}
%{_libdir}/libArcus.so.%{libver}

%files -n %{develname}
%license LICENSE cmake/COPYING-CMAKE-SCRIPTS
%{_includedir}/Arcus/
%{_libdir}/libArcus.so
%{_libdir}/cmake/Arcus/

%if %{with python}
%files -n python3-arcus
%license LICENSE
%doc README.md
%doc examples/example.py
%{python3_sitearch}/Arcus.so
%endif


%changelog
* Sun Mar 16 2025 daviddavid <daviddavid> 1:5.3.0-2.mga10
+ Revision: 2165159
- add patch to fix compatibility with protobuf v26.x and later

* Fri Feb 09 2024 daviddavid <daviddavid> 1:5.3.0-1.mga10
+ Revision: 2039861
- new version: 5.3.0
- disable python bindings for now (requires old sip4)

* Thu Dec 22 2022 wally <wally> 1:4.12.0-4.mga9
+ Revision: 1925777
- rebuild for protobuf 21.12

* Wed Mar 30 2022 umeabot <umeabot> 1:4.12.0-3.mga9
+ Revision: 1833844
- Mageia 9 Mass Rebuild

* Mon Feb 21 2022 tv <tv> 1:4.12.0-2.mga9
+ Revision: 1782163
- Rebuild for python-3.10

* Wed Dec 29 2021 wally <wally> 1:4.12.0-1.mga9
+ Revision: 1765198
- new version 4.12.0
- rebuild for protobuf 3.19.1

* Sat Mar 20 2021 daviddavid <daviddavid> 1:4.8.0-2.mga9
+ Revision: 1705923
- rebuild for python 3.9

* Mon Dec 28 2020 daviddavid <daviddavid> 1:4.8.0-1.mga8
+ Revision: 1664559
- new version: 4.8.0

* Fri Dec 18 2020 luigiwalser <luigiwalser> 1:4.4.1-4.mga8
+ Revision: 1660979
- rebuild for protobuf

* Mon Nov 30 2020 luigiwalser <luigiwalser> 1:4.4.1-3.mga8
+ Revision: 1650531
- rebuild for protobuf

* Sun Jun 28 2020 daviddavid <daviddavid> 1:4.4.1-2.mga8
+ Revision: 1600163
- rebuild for new protobuf 3.12.3

* Mon Feb 24 2020 daviddavid <daviddavid> 1:4.4.1-1.mga8
+ Revision: 1549891
- new version: 4.4.1 (add epoch as upstream changed its version scheme)
- split out the python bindings in his own sub-package
- now libmalor is 3

* Tue Feb 18 2020 daviddavid <daviddavid> 15.10-9.mga8
+ Revision: 1541102
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Thu Dec 19 2019 daviddavid <daviddavid> 15.10-8.mga8
+ Revision: 1468845
- rebuild for new protobuf 3.11.2

* Sat Sep 14 2019 daviddavid <daviddavid> 15.10-7.mga8
+ Revision: 1440714
- rebuild for python3.8

* Tue Jan 08 2019 daviddavid <daviddavid> 15.10-6.mga7
+ Revision: 1352698
- rebuild for new Python 3.7

* Fri Sep 21 2018 umeabot <umeabot> 15.10-5.mga7
+ Revision: 1294481
- Mageia 7 Mass Rebuild

* Sun Apr 15 2018 daviddavid <daviddavid> 15.10-4.mga7
+ Revision: 1219029
- rebuild for new protobuf 3.5
- remove no more needed protobuf-2.6.1 patch

* Sat Aug 05 2017 pterjan <pterjan> 15.10-3.mga7
+ Revision: 1135184
- Rebuild for python 3.6

* Thu Jan 05 2017 daviddavid <daviddavid> 15.10-2.mga6
+ Revision: 1080286
- add patch to fix build with protobuf 2.6.1

* Thu Dec 31 2015 ycantin <ycantin> 15.10-1.mga6
+ Revision: 917040
- imported package arcus

